### Toolhouse Restack AI integration

This integration can be used in your project to interact with Toolhouse AI.
Currently it exposes two functions that can be used in any workflow.
One function to send emails, using the send email tool from the toolhouse store. So make sure this tool is installed in your account.
The second function demostrates how you can fetch content from any url and have chat gpt give you a summary, this is using the get page contents.

### Tools

The following tools need to be installed on your toolhouse account.

[Get page contents](https://app.toolhouse.ai/store/scraper)
[Send Email with Sengrid](https://app.toolhouse.ai/store/send_email)
